@@ -243,71 +243,6 @@ tbl_group <- function(group) {
   purrr::map(group, ~spec[spec[[paste0("group_", .)]], ]$cdmTableName) %>% unlist() %>% unique()
 }
 
-#' Create a new Eunomia CDM
-#'
-#' Create a copy of the duckdb Eunomia CDM and return the file path
-#'
-#' @param exdir Enclosing directory where the Eunomia CDM should be created.
-#' If NULL (default) then a temp folder is created.
-#'
-#' @return The full path to the new Eunomia CDM that can be passed to `dbConnect()`
-#' @export
-#' @importFrom utils untar download.file menu
-#' @examples
-#' \dontrun{
-#' library(DBI)
-#' library(CDMConnector)
-#' con <- dbConnect(duckdb::duckdb(), dbdir = getEunomiaPath())
-#' dbListTables(con)
-#' dbDisconnect(con)
-#' }
-eunomia_dir <- function(exdir = NULL) {
-  rlang::check_installed("duckdb", version = "0.6.0", reason = "duckdb version 0.6 is required to use eunomia_dir()")
-  if (!eunomia_is_available() && interactive()) {
-    rc <- menu(c("Yes", "No"),
-              title = "Eunomia has not been downloaded yet.\nWould you like to download the Eunomia example CDM dataset?")
-  } else {
-    rc <- 1 # Automatically try downloading Eunomia if R is running non-interactively.
-  }
-
-  if (rc != 1) rlang::abort("Eunomia dataset is not available")
-
-  if (is.null(exdir)) exdir <- file.path(tempdir(TRUE), paste(sample(letters, 8, replace = TRUE), collapse = ""))
-  file <- xzfile(eunomia_cache(), open = "rb")
-  untar(file, exdir = exdir)
-  close(file)
-  path <- file.path(exdir, "cdm.duckdb")
-  if(!file.exists(path)) rlang::abort("Error creating Eunomia CDM")
-  return(path)
-}
-
-# has the eunomia dataset been cached?
-eunomia_is_available <- function() {
-  path <- Sys.getenv("EUNOMIA_CACHE_DIR", unset = "~/eunomia_cache")
-  path <- path.expand(path)
-  file.exists(file.path(path, "cdm.duckdb.tar.xz"))
-}
-
-# return the location to the cached eunomia dataset
-eunomia_cache <- function() {
-  path <- Sys.getenv("EUNOMIA_CACHE_DIR", unset = "~/eunomia_cache")
-  path <- path.expand(path)
-  if (!eunomia_is_available()) {
-    if (!dir.exists(path)) dir.create(path)
-
-    download.file("https://github.com/OdyOSG/EunomiaData/raw/main/cdm.duckdb.tar.xz",
-                  file.path(path, "cdm.duckdb.tar.xz"),
-                  method = "auto")
-  }
-  if (!eunomia_is_available()) rlang::abort("Error downloading Eunomia dataset.")
-
-  return(file.path(path, "cdm.duckdb.tar.xz"))
-}
-
-#' @export
-#' @describeIn eunomia_dir camelCase alias
-eunomiaDir <- eunomia_dir
-
 #' Get the database management system (dbms) from a cdm_reference or DBI connection
 #'
 #' @param con A DBI connection or cdm_reference
@@ -514,6 +449,3 @@ print.cdm_snapshot <- function(x, ...) {
   cli::cat_rule(x$cdm_source_name)
   purrr::walk2(names(x[-1]), x[-1], ~cli::cat_bullet(.x, ": ", .y))
 }
-
-setOldClass("cdm_reference")
-setOldClass("CohortSet")
