@@ -1,6 +1,9 @@
 ## ---- include = FALSE---------------------------------------------------------
+library(CDMConnector)
+if (!eunomia_is_available()) download_optional_data()
+
 installed_version <- tryCatch(utils::packageVersion("duckdb"), error = function(e) NA)
-build <- !is.na(installed_version) && installed_version >= "0.5"
+build <- !is.na(installed_version) && installed_version >= "0.6" && eunomia_is_available()
 
 knitr::opts_chunk$set(
   collapse = TRUE,
